@@ -68,7 +68,10 @@ def bulk(insee_region_names, date_=None, fetch_episodes=False, fetch_allergenes=
     close_insees = set()
     for insee in insees:
         region = get_region(region_name=insee_region_names[insee])
-        close_insee = region.Forecast().get_close_insee(insee)
+        try:
+            close_insee = region.Forecast().get_close_insee(insee)
+        except KeyError:
+            continue
         close_insees.add(close_insee)
     insees.update(close_insees)
 
@@ -87,7 +90,10 @@ def bulk(insee_region_names, date_=None, fetch_episodes=False, fetch_allergenes=
             continue
         region = get_region(region_name=insee_region_names[insee])
         f = region.Forecast()
-        close_insee = f.get_close_insee(insee)
+        try:
+            close_insee = f.get_close_insee(insee)
+        except KeyError:
+            continue
         if close_insee in indices:
             indices[insee] = indices[close_insee]
             continue
@@ -98,7 +104,10 @@ def bulk(insee_region_names, date_=None, fetch_episodes=False, fetch_allergenes=
                 continue
             region = get_region(region_name=insee_region_names[insee])
             e = region.Episode()
-            close_insee = e.get_close_insee(insee)
+            try:
+                close_insee = e.get_close_insee(insee)
+            except KeyError:
+                continue
             if close_insee in episodes:
                 episodes[insee] = episodes[close_insee]
                 continue
@@ -107,7 +116,7 @@ def bulk(insee_region_names, date_=None, fetch_episodes=False, fetch_allergenes=
         insee: {
             "forecast": make_resp(
                 get_region(region_name=insee_region_names[insee]).Forecast(),
-                indices[insee]
+                indices.get(insee, [])
                ),
         }
         for insee in insee_region_names.keys()
@@ -117,7 +126,7 @@ def bulk(insee_region_names, date_=None, fetch_episodes=False, fetch_allergenes=
             to_return[insee].update({
                 "episode": make_resp(
                     get_region(region_name=insee_region_names[insee]).Episode(),
-                    episodes[insee]
+                    episodes.get(insee, [])
                 )
                 }
             )
@@ -138,8 +147,13 @@ def bulk(insee_region_names, date_=None, fetch_episodes=False, fetch_allergenes=
         for insee in insees:
             if not insee in to_return:
                 continue
-            commune = Commune.get(insee)
-            code_departement = f"{commune.code_departement:0>2}" if commune.code_departement != '2A' and commune.code_departement != '2B' else '20'
+            if len(insee) == 5:
+                commune = Commune.get(insee)
+                code_departement = f"{commune.code_departement:0>2}" if commune.code_departement != '2A' and commune.code_departement != '2B' else '20'
+            elif len(insee) == 2:
+                code_departement = f"{insee:0>2}" if insee != '2A' and insee != '2B' else '20'
+            else:
+                code_departement = ""
             if code_departement in allergenes:
                 to_return[insee].update({
                     "raep" : allergenes[code_departement]
