@@ -24,8 +24,13 @@ class EpisodeHistory(db.Model):
             raise e
 
     @classmethod
-    def get(cls, date_,code_zone=None):
-        return db.session.query(cls).filter_by(date_=date_, code_zone=code_zone).first()
+    def get(cls, date_, code_zone=None, polluant=None):
+        query = db.session.query(cls).filter_by(date_=date_)
+        if code_zone:
+            query = query.filter_by(code_zone=code_zone)
+        if polluant:
+            query = query.filter_by(polluant=polluant)
+        return query.first()
     
     @classmethod
     def get_bulk(cls, date_, insee_list):
@@ -37,11 +42,14 @@ class EpisodeHistory(db.Model):
         diff = insee_list - set([c[0] for c in insee_code_zone_list])
         if len(diff) > 0:
             for insee in diff:
-                commune = Commune.get(insee)
-                if commune and commune.code_zone:
-                    insee_code_zone_list.append(
-                        (commune.insee, commune.code_zone)
-                    )
+                if len(insee) == 5:
+                    commune = Commune.get(insee)
+                    if commune and commune.code_zone:
+                        insee_code_zone_list.append(
+                            (commune.insee, commune.code_zone)
+                        )
+                elif len(insee) == 2:
+                    insee_code_zone_list.append((insee, insee))
         code_zone_list = [c[1] for c in insee_code_zone_list]
 
         return cls.query\
@@ -50,22 +58,33 @@ class EpisodeHistory(db.Model):
 
     @classmethod
     def get_after(cls, date_, insee):
-        commune = Commune.get(insee)
-        return [v.features for v in cls.query.filter(cls.date_ >= date_, cls.code_zone==commune.code_zone).all()]
+        if len(insee) == 5:
+            code_zone = Commune.get(insee).code_zone
+        else:
+            code_zone = insee
+        return [v.features for v in cls.query.filter(cls.date_ >= date_, cls.code_zone==code_zone).all()]
 
     @classmethod
     def get_or_create(cls, date_, insee=None, code_zone=None, features=None):
-        code_zone = code_zone or Commune.get(insee).code_zone
-        if code_zone:
-            result = cls.get(date_, code_zone=code_zone)
+        if not code_zone:
+            if insee and len(insee) == 5:
+                commune = Commune.get(insee)
+                if not commune.code_zone:
+                    commune.code_zone = str(features['code_zone'])
+                    db.session.add(commune)
+                    db.session.commit()
+                code_zone = commune.code_zone
+            if insee and len(insee) == 2:
+                code_zone = insee
+        if type(features) == dict:
+            polluant = features.get("code_pol") or features.get("code_polluant")
+        else:
+            polluant = None
+        if code_zone and polluant:
+            result = cls.get(date_, code_zone=code_zone, polluant=str(polluant))
             if result:
                 return result
-        commune = Commune.get(insee)
-        if not commune.code_zone:
-            commune.code_zone = str(features['code_zone'])
-            db.session.add(commune)
-            db.session.commit()
-        result = cls.get(date_, code_zone=commune.code_zone)
+        result = cls.get(date_, code_zone=code_zone, polluant=str(polluant))
         if result:
             return result
         result = cls(features)
